@@ -2,10 +2,10 @@
 # See LICENSE for details.
 
 __author__ = "Thinh Vu @thinh-vu in GitHub"
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 from .fullstory_api import (
-    fs_export,
+    fs_user_export,
     fs_GetUser,
     fs_list_segment,
     fs_segment_export,
